ext_attr

Function ext_attr 

pub fn ext_attr(input: TokenStream) -> TokenStream
Implementation of the __ext! proc macro.

This proc macro receives extension attribute invocations and forwards them to the extension crate’s dispatcher macro while preserving spans for better error messages.

Input format: ns::attr_name { field : Type }, @const ns::attr_name { ... }, etc. Output: ns::__attr!(@ns { ns } attr_name { ... }) (with optional @const prefix)